@@ -1,12 +1,12 @@
 package JSONAPI::Document::Builder::Relationships;
-$JSONAPI::Document::Builder::Relationships::VERSION = '1.9';
+$JSONAPI::Document::Builder::Relationships::VERSION = '2.0';
 =head1 NAME
 
 JSONAPI::Document::Builder::Relationships - Related Resource Document builder
 
 =head1 VERSION
 
-version 1.9
+version 2.0
 
 =head1 DESCRIPTION
 
@@ -98,7 +98,7 @@ sub build_links_document {
         Carp::confess('Missing required argument: api_url');
     }
 
-    my $relationship_type = $self->format_type($relationship);
+    my $relationship_type = $self->document_type($relationship);
 
     my $data;
     my $rel_info = $row->result_source->relationship_info($relationship);
@@ -106,13 +106,14 @@ sub build_links_document {
         $data = [];
         my @rs = $row->$relationship->all();
         foreach my $related_row (@rs) {
-            push @$data, { id => $related_row->id, type => $self->document_type($relationship_type) };
+            push @$data, { id => $related_row->id, type => $relationship_type };
         }
     } else {
         if (my $related_row = $row->$relationship) {
             $data = {
                 id   => $related_row->id,
-                type => $self->document_type($relationship_type) };
+                type => $relationship_type
+            };
         }
     }
 
@@ -120,8 +121,12 @@ sub build_links_document {
 
     return {
         links => {
-            self    => $self->api_url . '/' . $row_type . '/' . $row->id . "/relationships/$relationship_type",
-            related => $self->api_url . '/' . $row_type . '/' . $row->id . "/$relationship_type",
+            self => $self->api_url . '/'
+                . $row_type . '/'
+                . $row->id
+                . '/relationships/'
+                . $self->format_type($relationship),
+            related => $self->api_url . '/' . $row_type . '/' . $row->id . '/' . $self->format_type($relationship),
         },
         data => $data,
     };
